# rcr/python/testing: Unit tests for Python RCRBOUNDS package

This folder contains various tests for the Python **rcrbounds** module.

## Usage

The tests are designed to work with [pytest](https://docs.pytest.org/).

If you do not have pytest installed, you can install it by executing:
```
pip install -U pytest
```
from your command line.

You can then execute all of the tests by executing:
```
pytest
```
from the command line in this folder or its parent folder.
